@@ -15,7 +15,7 @@
 #' or search these catalogues using \code{search_catalogues()},
 #'
 #' @param cube character. A character string that is either the complete filename or (uniquely) in the filename of the data cube you want to
-#' download, e.g. "EQ09". The available filenames can be obtained using the helper function \code{get_available_filenames()}
+#' download, e.g. "EQ09". The available filenames can be obtained using the helper function \code{get_available_files()}
 #'
 #' @param path Local directory in which downloaded files should be stored. By default, `path`
 #'  takes the value set in the environment variable "R_READABS_PATH".
@@ -98,3 +98,55 @@ download_abs_data_cube <- function(catalogue_string,
 
   return(invisible(filepath))
 }
+
+#' Convenience function to download and tidy data cubes from
+#' ABS Labour Force, Australia, Detailed.
+#' @param cube character. A character string that is either the complete filename
+#' or (uniquely) in the filename of the data cube you want to download. Use
+#' `get_available_lfs_cubes()` to see a dataframe of options.
+#' @param path Local directory in which downloaded files should be stored.
+#' @return A tibble with the data from the data cube. Columns names are
+#' tidied and dates are converted to Date class.
+#' @examples
+#' read_lfs_datacube("EQ02")
+#' @export
+read_lfs_datacube <- function(cube,
+                              path = Sys.getenv("R_READABS_PATH", unset = tempdir())) {
+  options(timeout = 180)
+  file <- download_abs_data_cube(
+    catalogue_string = "labour-force-australia-detailed",
+    cube = cube,
+    path = path
+  )
+  df <- file |>
+    readxl::read_excel(
+      sheet = "Data 1",
+      skip = 3
+    ) |>
+    rename(date = 1) %>%
+    mutate(date = as.Date(date))
+
+  colnames(df) <- tolower(colnames(df))
+  colnames(df) <- gsub(" |-|:", "_", colnames(df))
+  colnames(df) <- gsub("\\(|\\)|\\'", "", colnames(df))
+
+  df
+}
+
+#' Show the available Labour Force, Australia, detailed data cubes that can be
+#' downloaded
+#' @export
+#' @details Intended to be used with \code{read_lfs_datacube()}. Call
+#' \code{read_lfs_datacube()} interactively, find the table of interest
+#' (eg. "LM1"), then use `read_lfs_datacube()`.
+#' @examples
+#'
+#' get_available_lfs_cubes()
+#'
+get_available_lfs_cubes <- function() {
+  all_files <- get_available_files("labour-force-australia-detailed")
+
+  all_files %>%
+    dplyr::filter(substr(file, 1, 1) != "6",
+                  !grepl("zip", file))
+}
